<?php


/**
 * Payment method callback: settings form.
 *
 * Returns form elements for the payment method's settings form included
 * as part of the payment method's enabling action in Rules
 */
function commerce_europabank_settings_form($settings = NULL) {
  $form = array();
  $languages = language_list();

  $settings = (array) $settings + array(
    'account' => 'test',
    'Uid' => '',
    'currency' => variable_get('commerce_default_currency', 'USD'),
    'error_message' => 'An error occured while processing your payment. Please try again or contact a site administrator when this happens again.',
    'language' => '',
    'shared_secret' => '',
    'server_secret' => '',
    'proxy_url' => '',
    'provider_url' => '',
    'language_list' => array(),
    'default_language' => 'nl',
    'user_language' => '0',
  );
  // BASIC settings.
  $form['account'] = array(
    '#type' => 'radios',
    '#title' => t('Europabank account'),
    '#options' => array(
      'test' => ('Test account - for testing purposes only'),
      'prod' => ('Production account - use for processing real transactions'),
    ),
    '#default_value' => $settings['account'],
  );
  $form['Uid'] = array(
    '#type' => 'textfield',
    '#title' => t('MPI Account number'),
    '#description' => t('Your Europabank account number'),
    '#default_value' => $settings['Uid'],
  );
  $form['currency'] = array(
    '#type' => 'select',
    '#title' => t('Currency code'),
    '#description' => t('Transactions can only be processed in one of the listed currencies.'),
    '#options' => commerce_europabank_currencies(),
    '#default_value' => $settings['currency'],
  );
  $form['error_message'] = array(
    '#type' => 'textfield',
    '#title' => t('Error message'),
    '#description' => t('This message is shown to the user when something goes wrong with te transaction.'),
    '#size' => 128,
    '#default_value' => $settings['error_message'],
    '#required' => TRUE,
  );
  // SECURITY settings.
  $form['provider_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Payment provider Url ( Url mpi)'),
    '#description' => t('The url to your payment gateway. <br /> e.g. https://www.ebonline.be/test/mpi/authenticate'),
    '#default_value' => $settings['provider_url'],
  );

  $form['shared_secret'] = array(
    '#type' => 'textfield',
    '#title' => t('Client secret'),
    '#description' => t('The shared client secret.'),
    '#default_value' => $settings['shared_secret'],
  );
  $form['server_secret'] = array(
    '#type' => 'textfield',
    '#title' => t('Server secret'),
    '#description' => t('The server secret.'),
    '#default_value' => $settings['server_secret'],
  );
  $form['proxy_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Proxy Url'),
    '#description' => t('Proxy Url where your images will be passed from. <br />e.g. https://www.ebonline.be/(test/)mpi/image'),
    '#default_value' => $settings['proxy_url'],
  );

  // LANGUAGE settings.
  $form['default_language'] = array(
    '#type' => 'select',
    '#title' => t('Default language'),
    '#description' => t('The language to send to europabank.'),
    '#options' => array(
      'nl' => 'NL',
      'en' => 'EN',
      'fr' => 'fr',
    ),
    '#default_value' => $settings['default_language'],
  );
  $form['user_language'] = array(
    '#type' => 'radios',
    '#title' => t("Send current user's language to europabank"),
    '#description' => t('Currently only nl/fr/en are supported by europabank. If the user has another language, the default language (see above) will be used'),
    '#options' => array(
      '1' => ('Yes'),
      '0' => ('No'),
    ),
    '#default_value' => $settings['user_language'],
  );
  // TODO: LAYOUT settings.
  $form['#submit'][] = 'commerce_europabank_settings_form_submit';
  return $form;
}



/**
 * Payment method callback: redirect form.
 *
 * returns form elements that should be submitted to the redirected
 * payment service
 */
function commerce_europabank_redirect_form($form, &$form_state, $order, $payment_method) {
  // Return an error if the enabling action's settings haven't been configured.
  if (empty($payment_method['settings']['Uid'])) {
    drupal_set_message(t('Europabank is not properly configured.<br /> No Europabank Uid has been specified.'), 'error');
    return array();
  }
  // Set feedback URLs.
  $settings = array(
    'return' => url('commerce_europabank/' . $order->order_id . '/process', array('absolute' => TRUE)),
    // Specify the current payment method instance ID in the notify_url.
    'payment_method' => $payment_method['instance_id'],
  );
  return commerce_europabank_build_redirect_form($form, $form_state, $order, $payment_method['settings'] + $settings);
}



/**
 * Helper function for the redirect_form callback.
 */
function commerce_europabank_build_redirect_form($form, &$form_state, $order, $settings) {
  // Builds an Europabank payment form from an order object.
  global $user;
  $wrapper = entity_metadata_wrapper('commerce_order', $order);

  // Get financial info.
  $currency_code = $wrapper->commerce_order_total->currency_code->value();
  $amount = $wrapper->commerce_order_total->amount->value();
  $customer_name = $wrapper->commerce_customer_billing->commerce_customer_address->name_line->value();

  // Build the data array that will be translated into hidden form values.
  // NOTE: keys should be uppercase for the SHA-1 security string.
  $hash_keys = commerce_europabank_hash_keys();
  $data = array(
    // General parameters.
    'Uid' => $settings['Uid'],
    'Orderid' => $order->order_number,
    'Amount' => $amount,
    'Description' => commerce_europabank_description($order),
    'Chname' => $customer_name,
    'Chemail' => $order->mail,
    'Beneficiary' => variable_get('site_name', ''),

    // Feedback URLs.
    // We will use the feedbackurl option as an extra security measure.
    'Feedbackurl' => url('commerce_europabank/callback', array('absolute' => TRUE)),
    'Feedbacktype' => 'OFFLINE',
    'Feedbackemail' => variable_get('site_mail', ''),
    'Merchantemail' => variable_get('site_mail', ''),
    'Redirecttype' => 'DIRECT',
    'Redirecturl' => $settings['return'],
  );

  if ($settings['user_language'] == 1) {
    global $language;
    $allowed_languages = _commerce_europabank_get_allowed_languages();
    if (in_array($language->language, $allowed_languages)) {
      $data['Chlanguage'] = $language->language;
    }
  }
  if (empty($data['Chlanguage'])) {
    $data['Chlanguage'] = $settings['default_language'];
  }

  $country = variable_get('europabank_chcountry', NULL);
  if (!empty($country)) {
    $data['Chcountry'] = $country;
  }

  // Allow modules to add or alter the data sent to Europabank before signing.
  drupal_alter('commerce_europabank_data', $data, $order, $settings);

  // Build the Europabank redirection URL.
  $url = $settings['provider_url'];
  $form['#action'] = $url;

  // Generate SHA-1 security string & add hidden parameters to form.
  $sha1_sig = '';
  $sha1suffix = $settings['shared_secret'];
  $vals = '';
  foreach ($data as $name => $value) {
    if (!empty($value)) {
      $value = trim($value);
      if (in_array($name, $hash_keys)) {
        // Build the SHA-1 string from all filled in parameters.
        $sha1_sig .= $value;
        $vals .= $name;
      }
      // Add the value as a hidden form element.
      $form[$name] = array('#type' => 'hidden', '#value' => $value);
    }
  }
  // Add shared secret to the hash.
  $sha1_sig = $sha1_sig . $sha1suffix;
  $form['Hash'] = array('#type' => 'hidden', '#value' => sha1($sha1_sig));

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit payment'),
  );
  $form['#pre_render'][] = 'commerce_europabank_form_modify';

  
  return $form;
}




/**
 * Custom_form_modify_handler($form).
 */
function commerce_europabank_form_modify($form) {
  if ($form['#id'] == 'commerce-europabank-redirect-form') {
    unset($form['form_token']);
    unset($form['form_build_id']);
    unset($form['form_id']);
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('submit payment'),
      '#name' => '',
    );
  }
  return $form;
} 


/**
 * Implements hook_redirect_form_validate().
 */
function commerce_europabank_redirect_form_validate($order, $payment_method) {
  return commerce_europabank_process_callback($order, $payment_method);
}
