<?php

/*
 * @file general helper functions for the commerce_europabank module
 */



/**
 * Europabank only allows hashes of these fields.
 */
function commerce_europabank_hash_keys() {
  return array('Uid' , 'Orderid' , 'Amount' , 'Description');
}


/**
 * Render the description.
 *
 * Used in the communication arrays with europabank mpi
 * 
 * @param object $order
 *   The order.
 */
function commerce_europabank_description($order) {
  return t('Order @order_number at @store', array(
    '@order_number' => $order->order_number,
    '@store' => variable_get('site_name', url('<front>', array(
      'absolute' => TRUE,
    ))),
  ));
}


/**
 * Get a list of enabled currencies.
 *
 * @TODO: figure out which currencies Europabank actually supports
 */
function commerce_europabank_currencies() {
  // Build a currency options list from all enabled currencies.
  $options = array();

  foreach (commerce_currencies(TRUE) as $currency_code => $currency) {
    $options[$currency_code] = t('@code - !name', array(
      '@code' => $currency['code'],
      '@symbol' => $currency['symbol'],
      '!name' => $currency['name'],
    ));

    if (!empty($currency['symbol'])) {
      $options[$currency_code] .= ' - ' . check_plain($currency['symbol']);
    }
  }
  return $options;
}

/**
 * Get a payment status and message based on Europabank status ID.
 *
 * @param string $status
 *   received Europabank status ID
 *
 * @return array
 *   key 'code' contains the commerce status
 *   key 'message' contains a textual representation of the Europabank status ID
 */
function commerce_europabank_feedback_status($status) {
  switch ($status) {

    case "AU":
      $st = COMMERCE_PAYMENT_STATUS_SUCCESS;
      $msg = t('Authorized');
      break;

    case "DE":
      $st = COMMERCE_PAYMENT_STATUS_FAILURE;
      $msg = t('Declined by bank');
      break;

    case "CA":
      $st = COMMERCE_PAYMENT_STATUS_FAILURE;
      $msg = t('Cancelled by client');
      break;

    case "EX":
      $st = COMMERCE_PAYMENT_STATUS_FAILURE;
      $msg = t('A technical error occurred');
      break;

    case "TI":
      $st = COMMERCE_PAYMENT_STATUS_FAILURE;
      $msg = t('The payment timed out.');
      break;

    default:
      $st = COMMERCE_PAYMENT_STATUS_FAILURE;
      $msg = t('Unknown feedback status');
      break;

  }
  return array(
    'code' => $st,
    'message' => $msg,
  );
}

/**
 * Get a list of allowed languages for europabank.
 *
 * @return array
 *   return array of languages
 */
function _commerce_europabank_get_allowed_languages() {
  return array(
    'nl',
    'fr',
    'en',
  );
}


/**
 * Get Europabank feedback from GET / POST parameters.
 */
function commerce_europabank_get_feedback() {
  $feedback = FALSE;
  if (isset($_REQUEST['Hash'])) {
    // Prepare the feedback values sent by Europabank for processing.
    // We don't use $_REQUEST since this includes the $_SESSION variables.
    $feedback = array_map('check_plain', $_GET + $_POST);
    unset($feedback['q']);
  }
  return $feedback;
}


/**
 * Get transaction with a specific Europabank ID.
 */
function commerce_europabank_get_payment_transaction($feedback) {
  $feedback_remote_id = $feedback['Id'];
  $query = new EntityFieldQuery();

  $result = $query
    ->entityCondition('entity_type', 'commerce_payment_transaction')
    ->propertyCondition('payment_method', 'europabank')
    ->propertyCondition('remote_id', $feedback_remote_id)
    ->execute();
  if (isset($result['commerce_payment_transaction']) && count($result['commerce_payment_transaction']) > 0) {
    $transaction = array_pop($result['commerce_payment_transaction']);
    return $transaction->transaction_id;
  }
  return FALSE;
}
